summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoDom.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kofficecore/KoDom.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficecore/KoDom.h')
-rw-r--r--lib/kofficecore/KoDom.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/lib/kofficecore/KoDom.h b/lib/kofficecore/KoDom.h
index 4d95a42b..688110f0 100644
--- a/lib/kofficecore/KoDom.h
+++ b/lib/kofficecore/KoDom.h
@@ -20,28 +20,28 @@
#ifndef KODOM_H
#define KODOM_H
-#include <qdom.h>
+#include <tqdom.h>
#include <koffice_export.h>
/**
* This namespace contains a few convenience functions to simplify code using QDom
* (when loading OASIS documents, in particular).
*
* To find the child element with a given name, use KoDom::namedItemNS.
*
* To find all child elements with a given name, use
- * QDomElement e;
- * forEachElement( e, parent )
+ * TQDomElement e;
+ * forEachElement( e, tqparent )
* {
* if ( e.localName() == "..." && e.namespaceURI() == KoXmlNS::... )
* {
* ...
* }
* }
* Note that this means you don't ever need to use QDomNode nor toElement anymore!
* Also note that localName is the part without the prefix, this is the whole point
* of namespace-aware methods.
*
* To find the attribute with a given name, use QDomElement::attributeNS.
*
* Do not use getElementsByTagNameNS, it's recursive (which is never needed in KOffice).
* Do not use tagName() or nodeName() or prefix(), since the prefix isn't fixed.
@@ -51,19 +51,19 @@
namespace KoDom {
/**
* A namespace-aware version of QDomNode::namedItem(),
* which also takes care of casting to a QDomElement.
* Use this when a domelement is known to have only *one* child element
* with a given tagname.
*
* Note: do *NOT* use getElementsByTagNameNS, it's recursive!
*/
- KOFFICECORE_EXPORT QDomElement namedItemNS( const QDomNode& node, const char* nsURI, const char* localName );
+ KOFFICECORE_EXPORT TQDomElement namedItemNS( const TQDomNode& node, const char* nsURI, const char* localName );
}
-#define forEachElement( elem, parent ) \
- for ( QDomNode _node = parent.firstChild(); !_node.isNull(); _node = _node.nextSibling() ) \
+#define forEachElement( elem, tqparent ) \
+ for ( TQDomNode _node = tqparent.firstChild(); !_node.isNull(); _node = _node.nextSibling() ) \
if ( !( elem = _node.toElement() ).isNull() )
#endif /* KODOM_H */
@@ -20,28 +20,28 @@
#include <koffice_export.h>
/**
- * This namespace contains a few convenience functions to simplify code using QDom
+ * This namespace contains a few convenience functions to simplify code using TQDom
* (when loading OASIS documents, in particular).
*
@@ -20,28 +20,28 @@
* }
* }
- * Note that this means you don't ever need to use QDomNode nor toElement anymore!
+ * Note that this means you don't ever need to use TQDomNode nor toElement anymore!
* Also note that localName is the part without the prefix, this is the whole point
* of namespace-aware methods.
@@ -20,28 +20,28 @@
* of namespace-aware methods.
*
- * To find the attribute with a given name, use QDomElement::attributeNS.
+ * To find the attribute with a given name, use TQDomElement::attributeNS.
*
* Do not use getElementsByTagNameNS, it's recursive (which is never needed in KOffice).
@@ -51,19 +51,19 @@
namespace KoDom {
/**
- * A namespace-aware version of QDomNode::namedItem(),
- * which also takes care of casting to a QDomElement.
+ * A namespace-aware version of TQDomNode::namedItem(),
+ * which also takes care of casting to a TQDomElement.
* Use this when a domelement is known to have only *one* child element
* with a given tagname.